@@ -1,5 +1,31 @@
 var NAVTREEINDEX33 =
 {
+"classopenvdb_1_1v12__0_1_1math_1_1Quat.html#ac9ca720e14833f50c05bee6f3de9185c":[14,0,6,0,5,139,23],
+"classopenvdb_1_1v12__0_1_1math_1_1Quat.html#ac9ca720e14833f50c05bee6f3de9185c":[15,0,4,0,4,138,23],
+"classopenvdb_1_1v12__0_1_1math_1_1Quat.html#acc3b773e5965248fb65922197958e3a9":[14,0,6,0,5,139,39],
+"classopenvdb_1_1v12__0_1_1math_1_1Quat.html#acc3b773e5965248fb65922197958e3a9":[15,0,4,0,4,138,39],
+"classopenvdb_1_1v12__0_1_1math_1_1Quat.html#ad0561ec473355048d1b49e9dc900193a":[14,0,6,0,5,139,22],
+"classopenvdb_1_1v12__0_1_1math_1_1Quat.html#ad0561ec473355048d1b49e9dc900193a":[15,0,4,0,4,138,22],
+"classopenvdb_1_1v12__0_1_1math_1_1Quat.html#ad1141e7b8d70721e8bbbcc8cd221d293":[14,0,6,0,5,139,12],
+"classopenvdb_1_1v12__0_1_1math_1_1Quat.html#ad1141e7b8d70721e8bbbcc8cd221d293":[15,0,4,0,4,138,12],
+"classopenvdb_1_1v12__0_1_1math_1_1Quat.html#ade560cba6b10bb7117afaccbf07c4fc5":[14,0,6,0,5,139,38],
+"classopenvdb_1_1v12__0_1_1math_1_1Quat.html#ade560cba6b10bb7117afaccbf07c4fc5":[15,0,4,0,4,138,38],
+"classopenvdb_1_1v12__0_1_1math_1_1Quat.html#adec4d6e4697fff19761dfb957ab203f2":[14,0,6,0,5,139,24],
+"classopenvdb_1_1v12__0_1_1math_1_1Quat.html#adec4d6e4697fff19761dfb957ab203f2":[15,0,4,0,4,138,24],
+"classopenvdb_1_1v12__0_1_1math_1_1Quat.html#ae1e206b98c0ad034bf0ae89b89d623c1":[14,0,6,0,5,139,28],
+"classopenvdb_1_1v12__0_1_1math_1_1Quat.html#ae1e206b98c0ad034bf0ae89b89d623c1":[15,0,4,0,4,138,28],
+"classopenvdb_1_1v12__0_1_1math_1_1Quat.html#ae88aad6ab980ed9ef001bbab4c1cbfbd":[14,0,6,0,5,139,61],
+"classopenvdb_1_1v12__0_1_1math_1_1Quat.html#ae88aad6ab980ed9ef001bbab4c1cbfbd":[15,0,4,0,4,138,61],
+"classopenvdb_1_1v12__0_1_1math_1_1Quat.html#ae9b08fca99a89639cd78a91152a64d5f":[14,0,6,0,5,139,46],
+"classopenvdb_1_1v12__0_1_1math_1_1Quat.html#ae9b08fca99a89639cd78a91152a64d5f":[15,0,4,0,4,138,46],
+"classopenvdb_1_1v12__0_1_1math_1_1Quat.html#aea60bacac9490ebd9edc4efd1d2f294c":[14,0,6,0,5,139,60],
+"classopenvdb_1_1v12__0_1_1math_1_1Quat.html#aea60bacac9490ebd9edc4efd1d2f294c":[15,0,4,0,4,138,60],
+"classopenvdb_1_1v12__0_1_1math_1_1Quat.html#aeac1fbe9cbd74a976f0f3bd4768cd202":[14,0,6,0,5,139,35],
+"classopenvdb_1_1v12__0_1_1math_1_1Quat.html#aeac1fbe9cbd74a976f0f3bd4768cd202":[15,0,4,0,4,138,35],
+"classopenvdb_1_1v12__0_1_1math_1_1Quat.html#aecaeabaa9da616ae42bb20787878260d":[14,0,6,0,5,139,1],
+"classopenvdb_1_1v12__0_1_1math_1_1Quat.html#aecaeabaa9da616ae42bb20787878260d":[15,0,4,0,4,138,1],
+"classopenvdb_1_1v12__0_1_1math_1_1Quat.html#aeefe128375e3fecc343fa076bb3b22ce":[14,0,6,0,5,139,20],
+"classopenvdb_1_1v12__0_1_1math_1_1Quat.html#aeefe128375e3fecc343fa076bb3b22ce":[15,0,4,0,4,138,20],
 "classopenvdb_1_1v12__0_1_1math_1_1Quat.html#af27a503fcdc1b13ced14334239e80604":[14,0,6,0,5,139,58],
 "classopenvdb_1_1v12__0_1_1math_1_1Quat.html#af27a503fcdc1b13ced14334239e80604":[15,0,4,0,4,138,58],
 "classopenvdb_1_1v12__0_1_1math_1_1Quat.html#af3bef0016a581a52e76531a3ea4db8d9":[14,0,6,0,5,139,19],
@@ -223,31 +249,5 @@ var NAVTREEINDEX33 =
 "classopenvdb_1_1v12__0_1_1math_1_1ScaleMap.html#af7667a71e1e96fe4107fbd502702ec62":[14,0,6,0,5,143,1],
 "classopenvdb_1_1v12__0_1_1math_1_1ScaleMap.html#af7667a71e1e96fe4107fbd502702ec62":[15,0,4,0,4,142,1],
 "classopenvdb_1_1v12__0_1_1math_1_1ScaleMap.html#af85ee40f40463736f028670509db2d01":[14,0,6,0,5,143,30],
-"classopenvdb_1_1v12__0_1_1math_1_1ScaleMap.html#af85ee40f40463736f028670509db2d01":[15,0,4,0,4,142,30],
-"classopenvdb_1_1v12__0_1_1math_1_1ScaleMap.html#afecad9ca105451b57b29458f92c13732":[14,0,6,0,5,143,11],
-"classopenvdb_1_1v12__0_1_1math_1_1ScaleMap.html#afecad9ca105451b57b29458f92c13732":[15,0,4,0,4,142,11],
-"classopenvdb_1_1v12__0_1_1math_1_1ScaleTranslateMap.html":[14,0,6,0,5,144],
-"classopenvdb_1_1v12__0_1_1math_1_1ScaleTranslateMap.html":[15,0,4,0,4,143],
-"classopenvdb_1_1v12__0_1_1math_1_1ScaleTranslateMap.html#a06d9d4d13be68c807d4fb2ffc9150fc8":[14,0,6,0,5,144,52],
-"classopenvdb_1_1v12__0_1_1math_1_1ScaleTranslateMap.html#a06d9d4d13be68c807d4fb2ffc9150fc8":[15,0,4,0,4,143,52],
-"classopenvdb_1_1v12__0_1_1math_1_1ScaleTranslateMap.html#a090c9ca4ff766842fc37edfc65c09e76":[14,0,6,0,5,144,28],
-"classopenvdb_1_1v12__0_1_1math_1_1ScaleTranslateMap.html#a090c9ca4ff766842fc37edfc65c09e76":[15,0,4,0,4,143,28],
-"classopenvdb_1_1v12__0_1_1math_1_1ScaleTranslateMap.html#a0c5b091fe6c9c7e35ab8c73fadbb034a":[14,0,6,0,5,144,39],
-"classopenvdb_1_1v12__0_1_1math_1_1ScaleTranslateMap.html#a0c5b091fe6c9c7e35ab8c73fadbb034a":[15,0,4,0,4,143,39],
-"classopenvdb_1_1v12__0_1_1math_1_1ScaleTranslateMap.html#a13a5faa8c799dc12d79ca5f23ed29c59":[14,0,6,0,5,144,6],
-"classopenvdb_1_1v12__0_1_1math_1_1ScaleTranslateMap.html#a13a5faa8c799dc12d79ca5f23ed29c59":[15,0,4,0,4,143,6],
-"classopenvdb_1_1v12__0_1_1math_1_1ScaleTranslateMap.html#a13c6cc4ac2470b61652c1852c08df1c8":[14,0,6,0,5,144,14],
-"classopenvdb_1_1v12__0_1_1math_1_1ScaleTranslateMap.html#a13c6cc4ac2470b61652c1852c08df1c8":[15,0,4,0,4,143,14],
-"classopenvdb_1_1v12__0_1_1math_1_1ScaleTranslateMap.html#a182de35ffb5ffa4ffd45e84681307fc2":[14,0,6,0,5,144,33],
-"classopenvdb_1_1v12__0_1_1math_1_1ScaleTranslateMap.html#a182de35ffb5ffa4ffd45e84681307fc2":[15,0,4,0,4,143,33],
-"classopenvdb_1_1v12__0_1_1math_1_1ScaleTranslateMap.html#a190c94b20fda48ae6342b573ba99ee25":[14,0,6,0,5,144,49],
-"classopenvdb_1_1v12__0_1_1math_1_1ScaleTranslateMap.html#a190c94b20fda48ae6342b573ba99ee25":[15,0,4,0,4,143,49],
-"classopenvdb_1_1v12__0_1_1math_1_1ScaleTranslateMap.html#a1a1ef80cf9b97272b4d1a18e7da20937":[14,0,6,0,5,144,38],
-"classopenvdb_1_1v12__0_1_1math_1_1ScaleTranslateMap.html#a1a1ef80cf9b97272b4d1a18e7da20937":[15,0,4,0,4,143,38],
-"classopenvdb_1_1v12__0_1_1math_1_1ScaleTranslateMap.html#a21b9de4de4c077758ed295b8e821a77f":[14,0,6,0,5,144,54],
-"classopenvdb_1_1v12__0_1_1math_1_1ScaleTranslateMap.html#a21b9de4de4c077758ed295b8e821a77f":[15,0,4,0,4,143,54],
-"classopenvdb_1_1v12__0_1_1math_1_1ScaleTranslateMap.html#a30854ad3c8f0dfb7404244765e08573c":[14,0,6,0,5,144,7],
-"classopenvdb_1_1v12__0_1_1math_1_1ScaleTranslateMap.html#a30854ad3c8f0dfb7404244765e08573c":[15,0,4,0,4,143,7],
-"classopenvdb_1_1v12__0_1_1math_1_1ScaleTranslateMap.html#a320882c0c92e2716dede1dc2592605c4":[14,0,6,0,5,144,19],
-"classopenvdb_1_1v12__0_1_1math_1_1ScaleTranslateMap.html#a320882c0c92e2716dede1dc2592605c4":[15,0,4,0,4,143,19]
+"classopenvdb_1_1v12__0_1_1math_1_1ScaleMap.html#af85ee40f40463736f028670509db2d01":[15,0,4,0,4,142,30]
 };
